# How to annotate molecular adaptors

Here we describe how to capture a molecular adaptor activity which is defined as the binding activity of a molecule that brings together two or more molecules through a selective, non-covalent, often stoichiometric interaction, permitting those molecules to function in a coordinated way.

Example 1: [TYROBP acts as an adaptor between a receptor and a downstream effector](http://noctua.geneontology.org/workbench/noctua-visual-pathway-editor/?model_id=gomodel%3A633b013300001197)

![A screenshot of a computer

Description automatically generated with medium confidence](data:image/png;base64...)

The molecular activity unit for molecular adaptor may include:

o **MF**: molecular adaptor activity ([GO:0060090](https://www.ebi.ac.uk/QuickGO/term/GO%3A0060090)) or one of its children

o **Has input** the two (or more) molecules it brings together.

o **BP**: the BP it participates in

o **CC**: the place where the activity occurs.

The relation with the downstream activity used is **“directly positively regulates”**

Example 2: When an adaptor brings together an enzyme and its substrate

![A screenshot of a computer

Description automatically generated with medium confidence](data:image/png;base64...)

The molecular activity is the same as above (MF, inputs, BP, CC)

But in that case, the relation with the downstream activity used is “**provides input for**”
